# 🪄 bluer-algo

🪄 `@algo` carries AI algo.  

```bash
pip install bluer-algo
```

|   |
| --- |
| [`image classifier`](./bluer_algo/docs/image_classifier) [![image](https://github.com/kamangir/assets/raw/main/swallow-model-2025-07-11-15-04-03-2glcch/evaluation.png?raw=true)](./bluer_algo/docs/image_classifier) an image classifier. |

# aliases

[@image_classifier](./bluer_algo/docs/aliases/image_classifier.md).

---

> for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-algo/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-algo/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-algo/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-algo/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-algo/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-algo/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-algo.svg)](https://pypi.org/project/bluer-algo/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-algo)](https://pypistats.org/packages/bluer-algo)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🪄 [`bluer_algo-4.247.1`](https://github.com/kamangir/bluer-algo).
